@@ -1,8 +1,7 @@
-from .sql_handler import Sql_Handler
 import psycopg2
 import json
 
-class Postgres_Handler(Sql_Handler):
+class Postgres_Handler:
     #Initializer that takes the values for connection
     def __init__(self, user_name, password, host, port, database):
         self.user_name = user_name
@@ -10,16 +9,6 @@ class Postgres_Handler(Sql_Handler):
         self.host = host
         self.port = port
         self.database = database
-        
-    #Methods from inherited abstract class
-    def define_columns(self, columns):
-        super().define_columns(columns)
-    
-    def set_table_name(self, table_name):
-        return super().set_table_name(table_name)
-        
-    def set_keywords(self, keywords): 
-        return super().set_keywords(keywords)
    
     # Used internally create to run query
     def __run_query(self, query, values):
@@ -55,10 +44,10 @@ class Postgres_Handler(Sql_Handler):
                 return f'Error: {ex}'
         
     #Select all rows 
-    def search_for_records(self):
+    def search_for_records(self, columns, keywords):
         payload = {}
     
-        query_value_list = self.__build_search_query()       
+        query_value_list = self.__build_search_query(keywords)       
 
         #Runs the query and returns the results
         results = self.__run_query(query_value_list[0], query_value_list[1])
@@ -66,13 +55,17 @@ class Postgres_Handler(Sql_Handler):
     
         return payload
 
-    def __build_search_query(self):
+    def __build_search_query(self, keywords):
         where_string = ''
         values_dict = {}
+        table_name_key = 'table_name'
         
         #Start of query string
         query = f"SELECT * FROM %(table_name)s"
-        values_dict['table_name'] = self.table_name
+        
+        if table_name_key not in keywords:
+            assert("Error: table_name required as argument")
+        values_dict[table_name_key] = keywords[table_name_key]
         
         #Keys for the StartDate and EndDate
         start_date_key = "SearchStartDate"
@@ -81,6 +74,8 @@ class Postgres_Handler(Sql_Handler):
         if len(self.keywords) != 0:
             #Iterates through the keywords to build search string
             for key, item in self.keywords.items():
+                if key == table_name_key: continue
+                
                 if where_string != '':
                     where_string += ' AND '
                 
@@ -100,7 +95,7 @@ class Postgres_Handler(Sql_Handler):
         return [query, values_dict]
         
     
-    def __format_search_results(self, results):
+    def __format_search_results(self, results, columns):
         formatted_rows = []
         records = ''
         error = ''
@@ -117,7 +112,7 @@ class Postgres_Handler(Sql_Handler):
                     formatted_row = {}
                     
                     for index, item in enumerate(row):
-                        formatted_row[self.columns[f"{index}"]] = f'{item}'
+                        formatted_row[columns[f"{index}"]] = f'{item}'
                     
                     formatted_rows.append(formatted_row)
 
